@@ -24,42 +24,49 @@ from cmd2 import (
 )
 
 DC_TOOLS = [ 'system-tools', 'dev-tools', 'app-services','dataset-services','dl-model-services','dl-model-training-services',
-                'dl-streamer-pipeline-services','edge-deployment-services','edge-inference-app-services',
-                'edge-to-cloud-app-services','k8s-services','intel-dev-tools']
-DC_COMMANDS = ['install', 'uninstall', 'enable', 'disable']
+                'dlstreamer-pipeline-services','edge-deployment-services','edge-inference-app-services',
+                'edge-to-cloud-app-services','k8s-services','intel-dev-tools','oneapi-toolkits','one-edge-building-blocks']
+DC_COMMANDS = ['install', 'uninstall']
+DC_COMMANDS_WE = ['install', 'uninstall', 'enable', 'disable']
 APP_COMMANDS = ['start', 'stop', 'restart']
 
 SUB_TOOLS={
   "system-tools":['sftp', 'ssh', 'vnc', 'no-machine','vim'],
-  "dev-tools":['docker', 'docker-compose','jupyter', 'n8n', 'openvino-2021.4','vscode'],
-  "app-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics','perf-analysis','rtsp-streamer','web-video-client'],  
+  "dev-tools":['code-editor-tools','container-runtimes','automation-and-configuration-tools'],
+  "app-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics'],  
   "dataset-services":['intel','partner','public','synthetic'],
-  "dl-model-services":['dl-model-tools', 'inference-runtimes', 'object-detection-models','object-recognition-models'],
+  "dl-model-services":['dl-model-tools', 'inference-runtimes','featured-dl-models'],
   "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks'],
-  "dl-streamer-pipeline-services":['audio-pipelines','dl-streamer-tools','multi-sensory-pipelines','video-pipelines'],
+  "dlstreamer-pipeline-services":['audio-pipelines','dlstreamer-tools','multi-sensory-pipelines','video-pipelines'],
   "edge-deployment-services":['cross-plane','health-check','mass','vpshere-vm'],
   "edge-inference-app-services":['healthcare','industrial','market-places','media','retail','safety-security','transportation'],
   "edge-to-cloud-app-services":['seo-samples','seo-reference-implementations','seo-3rd-party-applications'],
-  "k8s-services":['kind','kubespray','microk8s','minikube','openshift','rancher-k3s','rancher-rke2','smart-edge-open','starlingx','tanzu'],
-  "intel-dev-tools":['intel-auto-deploy','intel-auto-test','intel-code-scans','mgt-console']
+  "k8s-services":['kind','kubespray','microk8s','kubeadm','minikube','openshift','rancher-k3s','rancher-rke2','smart-edge-open','starlingx','tanzu'],
+  "intel-dev-tools":['intel-auto-deploy','intel-auto-test','intel-code-scans','mgt-console'],
+  "oneapi-toolkits":['ai-analytics-toolkit','base-toolkit','intel-vtune','iot-toolkit','scikit-learn','xgboost'],
+  "one-edge-building-blocks":['csp-services','inference-services']
 }
 
 TOOLS={
+  "code-editor-tools":['jupyter-notebook','jupyter-lab','atom','sublime-text','notepad++','vscode'],
+  "container-runtimes":['docker', 'docker-compose','containerd','cri-o'], 
+  "automation-and-configuration-tools":['ansible','chef','puppet'],  
   "dl-model-tools":['dl-model-benchmark', 'nncf', 'omz-tools', 'openvino-dl-workbench','openvino-model-server', 
-                    'openvino-training-extension', 'post-training-optimization-toolkit'],
+                    'post-training-optimization-toolkit'],
   "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onnx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
-  "model-zoo":['telemetry','analystics','perf-analysis','web-video-playback','rancher','OKD','tanzu'],
-  "data-engineering-tools":['cvat'],
-  "datasets":['emotion-recognition','face-detection','object-detection'],
+  "featured-dl-models":['bert-large-uncased-whole-word-masking-squad-int8-0001','deeplabv3','efficientdet-d0-tf','facenet-20180408-102900','mobilenet-ssd','object-detection-models','resnet-50-pytorch','ssdlite_mobilenet_v2','yolo-v4-tf'],
+  "model-zoo":['pytorch-model-zoo','tensorflow-hub'],
+  "data-engineering-tools":['cvat','datumaro'],
+  "datasets":['face-detection','face-mask-detection','fake-face-detection','flowers-recognition'],
   "object-detection-models":['face-detection-retail-0005','pedestrian-detection-adas-0002','person-detection-retail-0002','vehicle-detection-adas-0002'],
   "object-recognition-models":['age-gender-recognition-retail-0013','head-pose-estimation-adas-0001'],
-  "training-frameworks":['cnvrg','intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','one-api','sonoma-creek'],
-  "dl-streamer-tools":['dlstreamer','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-composer','gst-shark'],
+  "training-frameworks":['intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','openvino-training-extensions','sonoma-creek','sigopt','bigdl'],
+  "dlstreamer-tools":['dlstreamer-pipeline-framework','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-benchmark','gst-shark'],
   "audio-pipelines":['audio-event-detection-sample'],
   "video-pipelines":['action-recognition-sample','human-pose-estimation-sample','vehicle-pedestrian-tracking-sample','face-detection-classification-sample','gvapython-sample','metadata-publishing-sample'],
   "multi-sensory-pipelines":['multi-sensor-pipeline'],
   "healthcare":['brain-tumor-segmentation','monai','openfl'],
-  "industrial":['edge-controls-for-industrial','edge-insights-for-amr','edge-insights-for-industrial','industrial-surface-detect-detection','industrial-textline-recognition','rotor-bearing-defect-detector','textile-defect-classifier','weld-porosity-detection'],
+  "industrial":['edge-controls-for-industrial','edge-insights-for-amr','edge-insights-for-industrial','industrial-surface-defect-detection','industrial-textline-recognition','rotor-bearing-defect-detector','textile-defect-classifier','weld-porosity-detection'],
   "market-places":['artifactory','dev-catalog','kube-apps','mrs','rrk'],
   "media":['ad-insertion','cdn-transcode-sample','immersive-video-sample','open-visual-cloud','smart-city','video-curation-sample'],
   "retail":['automated-checkout','edgex','interactive-kisok-ai-chatbot','real-time-sensor-fusion-for-loss-detection','social-distancing-for-retail-settings'],
@@ -67,10 +74,20 @@ TOOLS={
   "transportation":['address-recognition-and-analytics','automatic-license-plate-recognition','cargo-management','drive-behavior-analytics','edge-insights-for-fleet','intelligent-traffic-management','public-transit-analytics','vehicle-event-recording','workzone-analytics'],
   "seo-samples":['openvino-sample-application-in-openness','sample-eaa-test-application','telemetry-sample','video-analytics-services-sample-application-in-openness'],
   "seo-reference-implementations":['intelligent-connection-management-for-automated-handover','smartvr–livestreaming-of-immersive-media','telehealth-remote-monitoring','wireless-network-ready-intelligent-traffic-management','wireless-network-ready-pcb-defect-detection','network-optimization-and-ai-inferencing-management-for-telepathology'],
-  "seo-3rd-party-applications":['a5gnetworks','herta','orbo','qwilt','radisys']
+  "seo-3rd-party-applications":['a5gnetworks','herta','orbo','qwilt','radisys'],
+  "csp-services":['aws-greengrass','azure-iot-central','azure-iot-edge','azure-iot-hub'],
+  "inference-services":['dlstreamer','dlstreamer-pipeline-server','openvino-container','openvino-model-server']
 
 }
 
+# List contains service which are having enable and disable scripts
+enable_list = ['sigopt','openvino-dl-workbench','onnx', 
+'dlstreamer','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-composer',
+'audio-event-detection-sample',
+'action-recognition-sample','human-pose-estimation-sample','vehicle-pedestrian-tracking-sample','face-detection-classification-sample','gvapython-sample','metadata-publishing-sample']
+
+enable_list_k8s = ['kind','microk8s','minikube','rancher-k3s']
+
 class DC(cmd2.Cmd):
     CUSTOM_CATEGORY = 'My Custom Commands'
     def __init__(self):
@@ -162,7 +179,7 @@ class DC(cmd2.Cmd):
         #dc_utils.aptGet_uninstall("vim")
         #dc_utils.aptGet_install("vim")
         self.poutput("Args: {}".format(statement.args))
-        argsList=statement.args.split(' ')        
+        argsList = statement.args.split(' ')        
         print("length of args:", len(argsList))
 
         
@@ -204,6 +221,8 @@ class DC(cmd2.Cmd):
         CMD_TOOLS=[]
         TM_TOOLS=[]
         APP_TOOLS=[]
+        CMD_TOOLS_WE=[]
+        CMD_TOOLS_WE1=[]
         index_dict={}      
         
         if begidx>3:
@@ -214,16 +233,24 @@ class DC(cmd2.Cmd):
                     # print("subtools:", SUB_TOOLS[t])
                     CMD_TOOLS = DC_COMMANDS
                     if t == "app-services":
-                       APP_TOOLS =APP_COMMANDS
-
+                       APP_TOOLS =APP_COMMANDS                
 
                 for st in TOOLS:
                     if line.__contains__(st):
-                        # print(TOOLS[st])
-                        TM_TOOLS = TOOLS[st]                    
-                        
+                        #print(TOOLS[st])
+                        TM_TOOLS = TOOLS[st] 
 
-        if len(TM_TOOLS) != 0:                
+            for k8s_t in SUB_TOOLS_1:
+                    if line.__contains__(k8s_t):
+                        if k8s_t in enable_list_k8s:
+                            CMD_TOOLS_WE1 = DC_COMMANDS_WE  
+            
+            # for et in TM_TOOLS: 
+            #     if line.__contains__(et):               
+            #         if et in enable_list:
+            #             CMD_TOOLS_WE = DC_COMMANDS_WE                       
+
+        if len(TM_TOOLS) != 0 and len(CMD_TOOLS_WE) == 0:                
             index_dict = {
                 1: DC_TOOLS,  # Tab complete food items at index 1 in command line
                 2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
@@ -231,12 +258,27 @@ class DC(cmd2.Cmd):
                 4: CMD_TOOLS  # Tab complete using path_complete function at index 3 in command line
                  
             }
+        # elif len(CMD_TOOLS_WE) != 0:                
+        #     index_dict = {
+        #         1: DC_TOOLS,  # Tab complete food items at index 1 in command line
+        #         2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
+        #         3: TM_TOOLS,
+        #         4: CMD_TOOLS_WE  # Tab complete using path_complete function at index 3 in command line
+                 
+        #     }
         elif len(APP_TOOLS) != 0:
             index_dict = {
                 1: DC_TOOLS,  # Tab complete food items at index 1 in command line
                 2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
                 3: APP_TOOLS,  # Tab complete using path_complete function at index 3 in command line
                 
+            }
+        elif len(CMD_TOOLS_WE1) != 0:
+            index_dict = {
+                1: DC_TOOLS,  # Tab complete food items at index 1 in command line
+                2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
+                3: CMD_TOOLS_WE1,  # Tab complete using path_complete function at index 3 in command line
+                
             }
         else:
             # print("Inside else")
@@ -259,3 +301,4 @@ def main():
 #    main()
 
 
+
